Twotter
=======

A class for scraping position data for BAS Air Unit assets from Latitude
Technologies WebSentinel private JSON API.

Quickstart

pip install twotter

Copy and edit twotter/twotter.json appropriately e.g. copy to ~/.twotter.json

$ twotter_snapshot /path/to/twotter.json
